@@ -368,7 +368,7 @@ void CBasePlayer::DrawCurResult()
 #define DRAW_BOX_TEXT(text)                               \
    {                                                      \
       CBox *box = new CBox(20, 270, 595, 33, 155, 40, 185); \
-      gpGeneral->PlaySound(SOUND_HINT);                   \
+      gpGeneral->PlaySound(SOUND_HINT+RandomLong(0,2));           \
       gpGeneral->DrawText(text, 30, 270, 255, 255, 24);   \
       UTIL_Delay(2000);                                   \
       delete box;                                         \
@@ -463,7 +463,7 @@ void CBasePlayer::DrawAllResult()
          gpGeneral->DrawText(va("%d %s", s * m_Result.r,                 \
             ((s * m_Result.r <= 1) ? msg("point") : msg("points"))),     \
             300, y, 255, 255, 255, 24);                                  \
-         gpGeneral->PlaySound(SOUND_HINT);                               \
+         gpGeneral->PlaySound(SOUND_HINT+RandomLong(0,2));                       \
          UTIL_Delay(1000);                                               \
          y += 26;                                                        \
       }                                                                  \
